@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Statistics::Covid::Utils;
 use Statistics::Covid::Datum;
@@ -67,12 +67,12 @@ sub	new {
 			};
 			if( ! $loadedOK ){ warn "error, failed to load module '$pn' (file '$pnf'), most likely provider does not exist '$pn'."; return undef }
 			my $providerObj = $pn->new({
-				'config-hash' => $config_hash,
+				'config-hash' => Storable::dclone($config_hash),
 				'debug' => $debug
 			});
 			if( ! defined $providerObj ){ warn "error, call to $pn->new() has failed."; return undef }
 			$providers{$pn} = $providerObj;
-			if( $debug > 0 ){ warn "provider added '$pn'." }
+			if( $debug > 0 ){ warn "provider added '$pn':\n".$providerObj->toString() }
 		}
 		$self->{'p'}->{'provider-objs'} = \%providers;
 	} else { warn "error, 'providers' was not specified, a list of provider names, e.g. 'UK::GOVUK' and/or 'World::JHU' must be provided."; return undef }
@@ -101,10 +101,11 @@ sub	fetch_and_store {
 		my $providerObj = $providers->{$pn};
 		my $datas = $providerObj->fetch();
 		if( ! defined $datas ){ warn "$pn : error, failed to fetch()."; return undef }
-		if( $debug > 0 ){ warn "$pn : fetched latest data." }
+		if( $debug > 0 ){ warn "$pn : fetched latest data OK." }
 		if( $self->save_to_file() ){
-			if( 1 != $providerObj->save_fetched_data_to_localfile($datas) ){ warn "error, failed to save the data just fetched to local file."; return undef }
-			if( $debug > 0 ){ warn "$pn : fetched data saved to local file." }
+			my $outbase = $providerObj->save_fetched_data_to_localfile($datas);
+			if( ! defined($outbase) ){ warn "error, failed to save the data just fetched to local file."; return undef }
+			if( $debug > 0 ){ warn "$pn : fetched data saved to local file, with this basename '$outbase'." }
 		}
 		my $objs = $providerObj->create_Datums_from_fetched_data($datas);
 		if( ! defined $objs ){ warn "$pn : error, failed to processed fetched data and create Datum objects."; return undef }
@@ -120,10 +121,10 @@ sub	fetch_and_store {
 			if( $debug > 0 ){ print STDOUT _db_insert_bulk_toString($ret, $rows_in_db_before, $rows_in_db_after) }
 			if( $ret->{'num-failed'} > 0 ){ warn "$pn : error, there were failed inserts into DB." }
 			my $dbfilename = $io->db_filename();
-			if( $dbfilename ne '' ){ print STDOUT "fetch_and_store() : saved data to database in '$dbfilename'.\n" }
+			if( $dbfilename ne '' ){ print STDOUT "$pn : fetch_and_store() : saved data to database in '$dbfilename'.\n" }
 		}
 	}
-	if( $debug > 0 ){ warn "fetched $num_fetched_total objects in total." }
+	if( $debug > 0 ){ warn "fetched $num_fetched_total objects in total and from all providers: '".join("','",sort keys %$providers)."'." }
 	# returns an arrayref of all the Datums JUST fetched (after being converted from raw data to objects)
 	return \@retObjs
 }
@@ -313,12 +314,12 @@ __END__
 =encoding UTF-8
 
 =head1 NAME
-Statistics::Covid - Fetch, store in DB, retrieve and analyse Covid-19 statistics from data providers
 
+Statistics::Covid - Fetch, store in DB, retrieve and analyse Covid-19 statistics from data providers
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =head1 DESCRIPTION
 
@@ -390,6 +391,24 @@ solidify.
 
 	print "datum rows in DB: ".$covid->db_count_datums()."\n"
 
+	use Statistics::Covid::Analysis::Plot;
+
+	# plot something
+	my $objs = $io->db_select({
+		conditions => {belongsto=>'UK', name=>{'like' => 'Ha%'}}
+	});
+	my $outfile = 'chartclicker.png';
+	my $ret = Statistics::Covid::Analysis::Plot::plot_with_chartclicker({
+        	'datum-objs' => $objs,
+		# saves to this file:
+	        'outfile' => $outfile,
+		# plot this column (x-axis is time always)
+        	'Y' => 'confirmed', 
+		# and make several plots, each group must have 'name' common
+	        'GroupBy' => ['name']
+	});
+	
+
 =head1 EXAMPLE SCRIPT
 
 C<script/statistics-covid-fetch-data-and-store.pl> is
@@ -451,7 +470,7 @@ of this distribution.
 			# in the case of SQLite, this is a filepath
 			# all non-existing dirs will be created (by module, not by DBI)
 			"dbdir" : "datazz/db",
-			"dbname" : "covid.sqlite",
+			"dbname" : "covid19.sqlite",
 			# how to handle duplicates in DB? (duplicate=have same PrimaryKey)
 			# only-better : replace records in DB if outdated (meaning number of markers is less, e.g. terminal or confirmed)
 			# replace     : force replace irrespective of markers
