@@ -234,6 +234,12 @@ sub	config_hash {
 	if( exists $inhash->{'fileparams'} ){ if( ! $self->fileparams($inhash->{'fileparams'}) ){ warn "error, call to fileparams() has failed."; return undef } }
 	return 1 # success
 }
+sub	toString {
+	my $self = $_[0];
+	return "DataProvider: ".$self->name().':'
+		."\nurls:\n   ".join("\n  ", map { $_->[0] } @{$self->urls()})
+		."\ndata files dir: ".$self->datafilesdir()
+}
 1;
 __END__
 # end program, below is the POD
