@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use parent 'Statistics::Covid::DataProvider::Base';
 
@@ -134,10 +134,15 @@ sub create_Datums_from_fetched_data {
 	}
 	return \@ret
 }
-# saves the input datas (a perl arrayref) to a local file (2nd parameter)
-# returns 0 on failure, 1 on success
+# saves data received as JSON and PL (perl variables)
+# into files specified by an optional basename (input param: $outbase)
+# OR if no outbase is specified, it creates one
+# as a timestamped id and the dir will be the datafielesdir()
+# as it was specified in its config during construction
 # '$datas' is an arrayref of
 # [ [url, data_received_string, data_as_perlvar] ]
+# this provider does not have any metadata, all data is received in 1 chunk
+# returns undef on failure or the basename if successful.
 sub save_fetched_data_to_localfile {
 	my $self = $_[0];
 	my $datas = $_[1]; # this is an arrayref of [url, data_received_string, data_as_perlvar]
@@ -147,16 +152,16 @@ sub save_fetched_data_to_localfile {
 		my $dataid = $self->create_data_id($datas);
 		if( ! defined $dataid ){
 			warn "error, call to ".'create_data_id()'." has failed.";
-			return 0;
+			return undef;
 		}
 		$outbase = File::Spec->catfile($self->datafilesdir(), $dataid);
 	}
 	my $outfile = $outbase . '.data.json';
-	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[0]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed."; return 0 }
+	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[0]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed."; return undef }
 	$outfile = $outbase . '.data.pl';
-	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[0]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed."; return 0 }
+	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[0]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed."; return undef }
 	print "save_fetched_data_to_localfile() : saved data to base '$outbase'.\n";
-	return 1;
+	return $outbase;
 }
 1;
 __END__
