@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use parent 'Statistics::Covid::DataProvider::Base';
 
@@ -158,9 +158,14 @@ sub create_data_id {
 	;
 	return $dataid
 }
-# returns 0 on failure, 1 on success
-# the 1st param is the data to save (which is a 2-array for metadata and data)
-# the 2nd param is the basename for the output files, 2 will be created (metadata and data)
+# OR if no outbase is specified, it creates one
+# as a timestamped id and the dir will be the datafielesdir()
+# as it was specified in its config during construction
+# '$datas' is an arrayref of 2 items (metadata and data)
+# [ [url, data_received_string, data_as_perlvar], [url, data_received_string, data_as_perlvar] ]
+# this provider has BOTH metadata and data
+# and so 2 output files will be written, one for each
+# returns undef on failure or the basename if successful
 sub save_fetched_data_to_localfile {
 	my $self = $_[0];
 	# this is an arrayref of [url, data_received_string, data_as_perlvar]
@@ -174,24 +179,24 @@ sub save_fetched_data_to_localfile {
 		my $dataid = $self->create_data_id($datas);
 		if( ! defined $dataid ){
 			warn "error, call to ".'create_data_id()'." has failed.";
-			return 0;
+			return undef;
 		}
 		$outbase = File::Spec->catfile($self->datafilesdir(), $dataid);
 	}
 	my $index = 0;
 	my $outfile = $outbase . '.meta.json';
-	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[$index]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed."; return 0 }
+	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[$index]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed."; return undef }
 	$outfile = $outbase . '.meta.pl';
-	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[$index]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed."; return 0 }
+	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[$index]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed."; return undef }
 	if( $debug > 0 ){ print STDOUT "save_fetched_data_to_localfile() : saved data to base '$outfile'.\n" }
 
 	$index++;
 	$outfile = $outbase . '.data.json';
-	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[$index]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed."; return 0 }
+	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[$index]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed."; return undef }
 	$outfile = $outbase . '.data.pl';
-	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[$index]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed."; return 0 }
+	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[$index]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed."; return undef }
 	if( $debug > 0 ){ print STDOUT "save_fetched_data_to_localfile() : saved data to base '$outfile'.\n" }
-	return 1;
+	return $outbase
 }
 1;
 __END__
