@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use parent 'Statistics::Covid::DataProvider::Base';
 
@@ -42,7 +42,7 @@ sub new {
 		'Referer'           => 'https://services9.arcgis.com/N9p5hsImWXAccRNI/arcgis/rest/services/Z7biAeD8PAkqgmWhxG2A/FeatureServer/1/query?f=json&where=Confirmed%20%3E%200&returnGeometry=false&spatialRel=esriSpatialRelIntersects&outFields=*&orderByFields=Confirmed%20desc%2CCountry_Region%20asc%2CProvince_State%20asc&resultOffset=0&resultRecordCount=250&cacheHint=true',
 		'TE'                => 'Trailers',
 		# we have our own default
-		#'User-Agent'        => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.19; rv:61.0) Gecko/20100101 Firefox/73.0',
+		#'User-Agent'        => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.20; rv:61.0) Gecko/20100101 Firefox/73.0',
 		'DNT'               => '1',
 		'Origin'            => 'https://www.arcgis.com',
 		] # end headers
@@ -56,7 +56,7 @@ sub new {
 	# and do set parameters specific to this particular data provider
 	$self->name('JHU'); # <<<< Make sure this is unique over all providers
 	$self->datafilesdir(File::Spec->catfile(
-		$self->datafilesdir(), # use this as prefix
+		$self->datafilesdir(), # use this as prefix it was set in config
 		'World', $self->name() # and append a dir hierarchy relevant to this provider
 	));
 
@@ -180,6 +180,15 @@ sub create_Datums_from_fetched_data {
 	}
 	return \@ret
 }
+# saves data received as JSON and PL (perl variables)
+# into files specified by an optional basename (input param: $outbase)
+# OR if no outbase is specified, it creates one
+# as a timestamped id and the dir will be the datafielesdir()
+# as it was specified in its config during construction
+# '$datas' is an arrayref of
+# [ [url, data_received_string, data_as_perlvar] ]
+# this provider does not have any metadata, all data is received in 1 chunk
+# returns undef on failure or the basename if successful
 sub save_fetched_data_to_localfile {
 	my $self = $_[0];
 	my $datas = $_[1]; # this is an arrayref of [url, data_received_string, data_as_perlvar]
@@ -189,18 +198,18 @@ sub save_fetched_data_to_localfile {
 		my $dataid = $self->create_data_id($datas);
 		if( ! defined $dataid ){
 			warn "error, call to ".'create_data_id()'." has failed.";
-			return 0;
+			return undef;
 		}
 		$outbase = File::Spec->catfile($self->datafilesdir(), $dataid);
 	}
 	my $index = 0;
 	my $outfile = $outbase . '.data.json';
 	my $aurl = $datas->[$index]->[0];
-	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[$index]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed for url '$aurl'."; return 0 }
+	if( ! Statistics::Covid::Utils::save_text_to_localfile($datas->[$index]->[1], $outfile) ){ warn "error, call to ".'save_text_to_localfile()'." has failed for url '$aurl'."; return undef }
 	$outfile = $outbase . '.data.pl';
-	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[$index]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed for url '$aurl'."; return 0 }
+	if( ! Statistics::Covid::Utils::save_perl_var_to_localfile($datas->[$index]->[2], $outfile) ){ warn "error, call to ".'save_perl_var_to_localfile()'." has failed for url '$aurl'."; return undef }
 	print "save_fetched_data_to_localfile() : saved data to base '$outbase'.\n";
-	return 1;
+	return $outbase;
 }
 1;
 __END__
