@@ -119,6 +119,8 @@ sub	new {
 		foreach my $k (@{$d->{'column-names'}}){ $c->{$k} = $params->[$i++] }
 	} else { warn "parameter can be a hashref or an arrayref with values"; return undef }
 
+	# TODO: automatically insert getters and setter subs for each column name in the schema
+
 	# now check if anything is left undef, this is an error
 	foreach my $k (@{$d->{'column-names'}}){
 		if( ! defined $c->{$k} ){
@@ -128,6 +130,13 @@ sub	new {
 	}
 	return $self
 }
+sub	column_value {
+	my $self = $_[0];
+	my $column_name = $_[1];
+	if( ! $self->column_name_is_valid($column_name) ){ die "column name '$column_name' does not exist." }
+	return $self->{'c'}->{$column_name}
+}
+sub	column_name_is_valid { return exists $_[0]->{'c'}->{$_[1]} }
 ###########
 #### Nothing to change below, the subs to implement and overwrite are those above
 ###########
