@@ -4,17 +4,10 @@ use 5.006;
 use strict;
 use warnings;
 
-use parent 'Statistics::Covid::IO::DualBase';
-
 use DateTime;
 
 our $VERSION = '0.19';
 
-# our constructor which calls parent constructor first and then does
-# things specific to us, like dates
-# create a Data item, either by supplying parameters as a hashref
-# of name=>value or as an array which must have as many elements
-# as the 'db-columns' items and in this order.
 sub	new {
 	my ($class, $params) = @_;
 	$params = {} unless defined $params;
