@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use DateTime;
 use DateTime::Format::Strptime;
@@ -200,6 +200,38 @@ sub	make_timestamped_string {
 	if( ! defined $dt ){ warn pp(\%dtparams)."\nerror, call to DateTime->now() has failed for the above params."; return undef }
 	return $dt->ymd('-') . '_' . $dt->hms('.')
 }
+# this will take an array of Datum objects and a set of one or more
+# (table) column names (attributes of each object), e.g. 'confirmed'
+# and will create a hash, where keys are column names
+# and values are arrays of the values for that column name for each object
+# in the order they appear in the input array.
+sub	datums2dataframe {
+	my $objs = $_[0];
+	my @groupby = defined($_[1]) ? @{$_[1]} : ();
+	my @column_names = @{$_[2]};
+
+	# make sure that all column_names exist
+	my $anobj = $objs->[0];
+	my ($acn, $agn, $agv, $m);
+	foreach $acn (@column_names){ if( ! $anobj->column_name_is_valid($acn) ){ warn "error, column name '$acn' does not exist."; return undef } }
+	foreach $agn (@groupby){ if( ! $anobj->column_name_is_valid($agn) ){ warn "error, group-by columns name '$agn' does not exist."; return undef } }
+
+	my %ret;
+	for $anobj (@$objs){
+		$agv = "";
+		for $agn (@groupby){
+			$agv .= $anobj->column_value($agn).'|';
+		} $agv =~ s/\|$//;
+		if( ! exists $ret{$agv} ){
+			$ret{$agv} = $m = {};
+			for $acn (@column_names){ $m->{$acn} = [] }
+		} else { $m = $ret{$agv} }
+		for $acn (@column_names){
+			push @{$m->{$acn}}, $anobj->column_value($acn)
+		}
+	}
+	return \%ret
+}
 1;
 __END__
 # end program, below is the POD
